'Command Line Parameter 1: Component or Product
'Command Line Parameter 2: Component Name
'Command Line Parameter 3: Component Version
'Command Line Parameter 4: Component Build

Option Explicit

Private moShell

'Run the main function
Main

Function Main()

    WScript.Echo "Main: Entry Point"

    Dim loArgs, liIndex, llExitCode
    Dim CompOrProduct, Name, Version, Build

    llExitCode = 1

    'Create some global variables
    Set moShell = WScript.CreateObject("WScript.Shell")

    Set loArgs = WScript.Arguments

    'Trace all the arguments regardless of whether or not they are Named or Unnamed
    For liIndex = 0 To loArgs.Count - 1
        WScript.Echo "Main: Command Line Argument(" & liIndex & "): " & loArgs(liIndex)
    Next

    If WScript.Arguments.Named.Exists("T") Then CompOrProduct = WScript.Arguments.Named.Item("T")
    If WScript.Arguments.Named.Exists("N") Then Name = WScript.Arguments.Named.Item("N")
    If WScript.Arguments.Named.Exists("V") Then Version = WScript.Arguments.Named.Item("V")
    If WScript.Arguments.Named.Exists("B") Then Build = WScript.Arguments.Named.Item("B")

    WScript.Echo "CompOrProduct: " & CompOrProduct
    WScript.Echo "Name: " & Name
    WScript.Echo "Version: " & Version
    WScript.Echo "Build: " & Build
    
    'Note: The Build Number is optional for components
    If (CompOrProduct <> "") And (Name <> "") And (Version <> "") Then

        If Left(LCase(CompOrProduct), 6) = "legacy" Then

            llExitCode = UpdateLegacyRegistry(CompOrProduct, Name, Version, Build)

        Else

            llExitCode = UpdateRegistry(CompOrProduct, Name, Version, Build)

        End If

    End If

    Set moShell = Nothing

    WScript.Echo "Main: Exit Point, ExitCode: " & llExitCode

    WScript.Quit (llExitCode)

End Function

Function UpdateRegistry(CompOrProduct, Name, Version, Build)

    WScript.Echo "UpdateRegistry: Entry Point"

    Dim lStatus

    UpdateRegistry = 1

    'Delete any current information
    lStatus = moShell.Run("reg.exe delete " & Chr(34) & "HKLM\Software\NCR Americas PS\" & _
                          CompOrProduct & "\" & Name & Chr(34) & " /f", 0, True)

    'Add Version information
    lStatus = moShell.Run("reg.exe add " & Chr(34) & "HKLM\Software\NCR Americas PS\" & _
                          CompOrProduct & "\" & Name & Chr(34) & " /v Version /d " & Chr(34) & Version & Chr(34) & " /f", 0, True)

    'Add Build Number information
    If Build <> "" Then
        lStatus = moShell.Run("reg.exe add " & Chr(34) & "HKLM\Software\NCR Americas PS\" & _
                              CompOrProduct & "\" & Name & Chr(34) & " /v Build /d " & Chr(34) & Build & Chr(34) & " /f", 0, True)
    End If

    'Add Install Date information
    lStatus = moShell.Run("reg.exe add " & Chr(34) & "HKLM\Software\NCR Americas PS\" & _
                          CompOrProduct & "\" & Name & Chr(34) & " /v InstallDate /d " & Chr(34) & FormatDateTime(Date, 2) & Chr(34) & " /f", 0, True)

    'Add Install Time information
    lStatus = moShell.Run("reg.exe add " & Chr(34) & "HKLM\Software\NCR Americas PS\" & _
                          CompOrProduct & "\" & Name & Chr(34) & " /v InstallTime /d " & Chr(34) & FormatDateTime(Time(), 4) & Chr(34) & " /f", 0, True)

    UpdateRegistry = 0

    WScript.Echo "UpdateRegistry: Exit Point"

End Function

Function UpdateLegacyRegistry(CompOrProduct, Name, Version, Build)

    WScript.Echo "UpdateLegacyRegistry: Entry Point"

    Dim lStatus
    Dim sVersionDotBuild

    UpdateLegacyRegistry = 1

    If Build <> "" Then
        sVersionDotBuild = Version & "." & Build
    Else
        sVersionDotBuild = Version
    End If

    'Add Version (and possibly Build) information
    lStatus = moShell.Run("reg.exe add " & Chr(34) & "HKLM\Software\NCR\VERSIONS" & Chr(34) & _
                          " /v " & Chr(34) & Name & Chr(34) & " /d " & Chr(34) & sVersionDotBuild & Chr(34) & " /f", 0, True)

    'Add Installed Date and Time information
    lStatus = moShell.Run("reg.exe add " & Chr(34) & "HKLM\Software\NCR\VERSIONS" & Chr(34) & _
                          " /v " & Chr(34) & Name & " Installed" & Chr(34) & " /d " & Chr(34) & _
                          FormatDateTime(Date, 2) & " at " & FormatDateTime(Time(), 4) & Chr(34) & " /f", 0, True)

    UpdateLegacyRegistry = 0

    WScript.Echo "UpdateLegacyRegistry: Exit Point"

End Function
